*Data Stata Dofile 3   DatasetBuilding_Public
*HIV40 Mortality Paper: Dataset Building (Cleaned, Abriged Script)
*Created by Andrea Tilstra March 18, 2022
*Edited by Jane Menken: April 24, 2022 and July 8, 2022
*Runs on STATA15 or later

*Notes:

/** 	The AHDSS_Ha_Nakekela_HIV_Hyp_Sample.dta is a non-public dataset that includes information from 
		* the Agincourt Health and socioDemographic Surveillance System (AHDSS) 
			- on the age/sex stratified probability sample of 7657 individuals from the 2009 AHDSS Census
			  selected for the Ha Nakekela Survey	 
			- demographic and socioeconomic characteristics of individuals in the sample taken
			  from the 2009 and earlier AHDSS Censuses
			- dates of departure (death, migration, censoring) of individuals through July 31, 2019
		* the 2010-2011 Ha Nakekela (We Care) HIV and NCD Survey
			- survey outcome (participant, not found, dead before survey date, refused, ineligible) 
			- HIV and blood pressure measures

**/

/**		This do-file creates a person-year dataset for the HIVafter40 study of the impact of the twin epidemics 
		of HIV and hypertension on mortality. It: 
		* drops sample individuals with outcomes not found, dead before survey date, ineligible
		* retains data on person-years in which a participant in the Ha Nakekela Survey was age 40+
			  (including those who refused HIV test)
		* and creates a publicly available person-year data set: HIVafter40_Twin_Epidemics_HIV_NCD.dta
		* the dataset is the basis for the paper: ADD CITATION
**/


**use "AHDSS_HaNakekela_HIV_Hyp_Sample.dta", clear


************************************************************
* Variable Cleaning *
************************************************************

gen test_outcomeN = .
replace test_outcome = 0 if FinalHIVStatus == "NEGATIVE"
replace test_outcome = 1 if FinalHIVStatus == "POSITIVE" 
replace test_outcome = 2 if Outcome == 1 & FinalHIVStatus == "" //refused to test
replace test_outcome = 3 if Outcome == 4 //refusal
replace test_outcome = 4 if Outcome == 2 //not found

label define interview_outcome 0 "negative" 1 "positive" 2 "refused test" 3 "refused survey" 4 "not found" 
label values test_outcome interview_outcome
label var test_outcome "0-4 Neg/Pos/not found/refusal test/
* test_outcome=. if individual died before survey (162) or was found ineligible at survey (212)
* individuals will be dropped if test_outcome==.

tab test_outcome LastExitType
tab test_outcome LastExitType, row nof

gen exit_date = LastObsDate
replace exit_date = dofc(exit_date) 
format exit_date %td

gen entry = VisitDate
format entry %td

rename Age20100801 age
recode age (0/29=15) (30/49=30) (50/64=50) (65/max=65), gen(age_grp)
label define age_grp_lab 15 "15-29" 30 "30-49" 50 "50-64" 65 "65+" 
label values age_grp age_grp_lab
label var age_grp "Age cutoffs 30/50/65

* compute death indicator variable
gen dead = 0
replace dead = 1 if maxDoD != .
label var dead "Death recorded in AHDSS

gen male = Gender == "M"
label define male_lab 0 "female" 1 "male"
label values male male_lab

gen edu = . 
replace edu = 1 if EduYears <= 3
replace edu = 2 if EduYears > 3 & EduYears <=8
replace edu = 3 if EduYears > 8

label define edu_lab 1 "None/very low (<= 3 years)" ///
	2 "Primary(4-8 years)" ///
	3 "Secondary school or higher (>8 years)"
label values edu edu_lab
label var edu "Edu Low/Primary/Secondary+

//create numeric variable for marital status
replace UnionStatus =ltrim(rtrim(UnionStatus))
gen marital_sts=.
replace marital_sts= 0 if UnionStatus=="NeverInUnion"
replace marital_sts= 1 if UnionStatus=="Informal"
replace marital_sts= 2 if UnionStatus=="Formal"
replace marital_sts= 3 if UnionStatus=="Separated"
replace marital_sts= 3 if UnionStatus=="Divorced"
replace marital_sts= 4 if UnionStatus=="Widowed"
replace marital_sts= 5 if UnionStatus==""
replace marital_sts= 5 if marital_sts==.
label define marital_sts_lab 0 "Single" 1 "Cohabiting" ///
	2 "Married" 3 "Separated/divoced" 4 "Widowed" 5 "Missing"
label values marital_sts marital_sts_lab
label var marital_sts "5 category status

gen south_african = Refugee =="N"
label define south_african_lab 1 "south african" 0 "other"
label values south_african south_african_lab

gen working = 1 if CurrentlyWorking == "Y"
replace working = 0 if CurrentlyWorking == "N"
label define working_lab 1 "working" 0 "not working"
label values working working_lab
label var working "Currently working

rename qSESabs2009 qses
destring qses, replace
label var qses "Household wealth 2009 census quintile

** label values of 1=yes/2=no variables
label define yesno 1 "Yes" 2 "No"
label values Q38 yesno
label values Q39 yesno
label values Q41a yesno
label values Q41b yesno
label values Q41c yesno
label values Q41d yesno
label values Q41e yesno
label values Q41f yesno
label values Q8d yesno

label define Q8i 1 "Have ART" 2 "No ART" 3 "Refused to answer"
label values Q8i Q8i

gen outcome=Outcome
label define survout 1 "participant" 2 "not found" 3 "dead before survey date" 4 "refused" 5 "ineligible"
label values outcome survout 
order outcome,after(Outcome)

********************************
* Checks & Data Restrictions *
********************************

*checking when entry preceeded exit 
gen check = exit_date-entry
tab check if check<0
* 156 people had check<0. They all migrated out between selection and survey date
* will drop those w/ an exit before entry

****************
* Cleaning Covariates *
****************

*Covariates (based on incidence paper):
*sex (1= male, 0 = female)
tab male,mi
tab male, nol

*age (15 = 15-29, 30=30-49, 50=50-64, 65=65+)
tab age_grp, mi
tab age_grp, nol

*education (1= none/v low, 2=primary, 3=secondary or higher, 4=missing)
tab edu, mi
tab edu, nol

*marital status (0=single, 1=cohabitating, 2=married, 3=separated/divorced, 4=widowed, 5=missing)
* Then, collapsing marital status into: 1=single, 2=married/cohabiting, 3=widowed/divorced
tab marital_sts, mi
tab marital_sts, nol

gen mar3 = .
replace mar3 = 1 if marital_sts==0
replace mar3 = 2 if marital_sts==1|marital_sts==2
replace mar3 = 3 if marital_sts==3|marital_sts==4
label var mar3 "Single/Married_Cohabiting/Divorced_Widowed

label define mar_labels 1 "Single" 2 "Married/cohabiting" 3 "Widowed/divorced"
label values mar3 mar_labels

*nationality (1=south african, 0 = other)
tab south_african, mi
tab south_african, nol

*employment status (1=working, 0=not working, .=missing)
tab working, mi
tab working, nol

*household wealth quintile (1-5, .=missing)
tab qses, mi
tab qses, nol
*Per convo w/ J & B, we are collapsing wealth into 1=1&2, 2=3, 3=4&5

gen qses3 = .
replace qses3 = 1 if qses==1|qses==2
replace qses3 = 2 if qses==3
replace qses3 = 3 if qses==4|qses==5
label var qses3 "Household wealth quintile 1-2/3/4-5
label define qses3 1 "quint 1/2" 2 "quint 3" 3 "quint 4/5"
label values qses3 qses3

********************************
*Hypertension Variable Cleaning
********************************

rename Q*, lower

summ q68a_systolic1 q69a_systolic2 q70a_systolic3		// range 40-300 mmHg
	replace q68a_systolic1 = . if (q68a_systolic1>300 | q68a_systolic1<40)
	replace q69a_systolic2 = . if (q69a_systolic2>300 | q69a_systolic2<40)
	replace q70a_systolic3 = . if (q70a_systolic3>300 | q70a_systolic3<40)

* BP average of last 2 measures
egen systolic2 = rowmean(q69a_systolic2 q70a_systolic3) if !missing(q69a_systolic2, q70a_systolic3)
	label var systolic2 "Mean systolic mmHg"

gen histbpmed = .
	replace histbpmed = 1 if q41a_drugsforhighbplast2weeks==1 | q41b_drugsforhighbplast12months==1
	replace histbpmed = 0 if q39_diagnosedwithhighbp==2
	replace histbpmed = 0 if q38!=. & histbpmed==.
	label var histbpmed "History of HTN medication"
	label val histbpmed noyes

*Diastolic, for a datacheck later
summ q68b_diastolic1 q69b_diastolic2 q70b_diastolic3	// range 30-200 mmHg
	replace q68b_diastolic1 = . if (q68b_diastolic1>200 | q68b_diastolic1<30)
	replace q69b_diastolic2 = . if (q69b_diastolic2>200 | q69b_diastolic2<30)
	replace q70b_diastolic3 = . if (q70b_diastolic3>200 | q70b_diastolic3<30)
egen diastolic2 = rowmean(q69b_diastolic2 q70b_diastolic3) if !missing(q69b_diastolic2, q70b_diastolic3)
	label var diastolic2 "Mean diastolic mmHg"
	
* create composite of if receiving any treatment
gen hypertension_tx = .
replace hypertension_tx= 1 if q41a_drugsforhighbplast2weeks==1
replace hypertension_tx= 1 if q41b_drugsforhighbplast12months==1
replace hypertension_tx= 1 if q41c_advicetoreducesalt_bp==1
replace hypertension_tx= 1 if q41d_advicetoloseweight_bp==1
replace hypertension_tx= 1 if q41e_advicetostopsmoking_bp==1
replace hypertension_tx= 1 if q41f_advicetoexercise_bp==1
label var hypertension_tx "Received hyp treatment/advice

* q39_diagnosedwithhighbp (1=yes, told had high BP; 2= no, not told had high BP)
gen hypertension_report = .
replace hypertension_report = 1 if q39_diagnosedwithhighbp==1
replace hypertension_report = 0 if q39_diagnosedwithhighbp==2
label var hypertension_report "1 q39=1 0 q39=2
label define hyprep 0 "not told had high BP" 1 "told had high BP"
label values hypertension_report hyprep


cap drop hyp_control_uncontrol
gen hyp_control_uncontrol = .
            replace hyp_control_uncontrol = 0 if hypertension_report==0 & hypertension_tx!=1
            replace hyp_control_uncontrol = 1 if hypertension_report==0 & hypertension_tx==1
            replace hyp_control_uncontrol = 2 if hypertension_report==1 & hypertension_tx!=1
            replace hyp_control_uncontrol = 3 if hypertension_report==1 & hypertension_tx==1
            cap label define hyp_control_uncontrol 0 "Not hypertensive, no tx" 1 "Not hypertensive, on tx" ///
                        2 "Hypertensive, no tx" 3 "Hypertensive, on tx"
                        label val hyp_control_uncontrol hyp_control_uncontrol
                        label var hyp_control_uncontrol "Hypertension report & treatment

recode hyp_control_uncontrol (3=1), gen(hyp_tx)
		cap label define hyp_tx 0 "Normotensive" 1 "Hypertensive, on tx" 2 "Hypertensive, not on tx"
		label val hyp_tx hyp_tx
		label var hyp_tx "Normotensive/Hyp-tx/Hyp-no tx"

		tab hyp_control_uncontrol hyp_tx, m

*simple hypertension variable
gen hyp_simple = .
replace hyp_simple = 0 if hyp_tx==0
replace hyp_simple = 1 if hyp_tx==1|hyp_tx==2
		cap label define hyp_simple 0 "Normotensive" 1 "Hypertensive: reported or treated"
		label var hyp_simple "Normotensive/Hypertensive
		label val hyp_simple hyp_simple
		
*SBP categories
gen sbp_cat2 = .
replace sbp_cat2 = 1 if systolic2<120
replace sbp_cat2 = 2 if systolic2>=120 & systolic2<=139
replace sbp_cat2 = 3 if systolic2>=140 & systolic2<=159
replace sbp_cat2 = 4 if systolic2>=160 & systolic2!=.
label var sbp_cat2 "Systolic cutoffs 120/140/160
label define sbp 1 "<120" 2 "120-139" 3 "140-159" 4 "160+"
label val sbp_cat2 sbp

*************************
*HIV Variable Cleaning
*************************

*Creating binary HIV indicator
gen hiv_positive = .
replace hiv_positive = 1 if FinalHIVStatus=="POSITIVE"
replace hiv_positive = 0 if FinalHIVStatus=="NEGATIVE"
label define hiv_p 0 "Negative" 1 "Positive"
label values hiv_positive hiv_p

*Change in HIV indicator: 
* 1 = negative; 2= unknown; 3= positive, no prev test, no ART,
*		4 = positive, prev test, no ART; 5 = positive, ART
* Q8d_EverTestedForHIV : 1 = yes ever tested, 2= no never tested
* Q8i_UnderAntiretroviralTreatment: 1= yes, have ART; 2 = no ART; 3 = refuse to answer

gen hiv5 = .
replace hiv5 = 1 if hiv_positive == 0
replace hiv5 = 3 if hiv_positive == 1 & q8d_evertestedforhiv == 2
replace hiv5 = 4 if hiv_positive == 1 & q8d_evertestedforhiv == 1 & q8i_underantiretroviraltreatment == 2
replace hiv5 = 5 if hiv_positive == 1 & q8d_evertestedforhiv == 1 & q8i_underantiretroviraltreatment == 1
replace hiv5 = 2 if hiv5==.

label define hiv_var 1 "negative" 2 "unknown" 3 "positive, no prev. test, no ART" 4 "positive, prev test, no ART" 5 "positive, ART"
label values hiv5 hiv_var
label var hiv5 "1 negative 2 unknown 3-5 HIVpos/test/ART treatment status 

* Clean the original viral load variable
clonevar viralload = ViralLoad

* Assuming these should be excluded
replace viralload = "" if inlist(viralload, "INSUFFICIENT", "INVALID", "insufficient")

* Not sure if undetectable should be dropped, not for now -> 0
replace viralload = "0" if inlist(viralload, "<2.00", "<2.0", "<2", "<1.60", "<1.6")

destring viralload, gen(vl_num)
	label var viralload "Log viral load, undetectable = 0"

* Convert to raw values
cap drop vl_exp
gen vl_exp = 10^vl_num
	label var vl_exp "Raw viral load"

*Final HIV Variable: 400 as the cutoff
gen vl_simple_400 = . 
	replace vl_simple_400 = 0 if hiv5 == 1
	replace vl_simple_400 = 1 if vl_exp <= 400
	replace vl_simple_400 = 2 if vl_exp > 400 & !missing(vl_exp)
	cap label define vl_simple_400 0 "HIV Negative" 1 "Suppressed<=400" 2 "Unsuppressed>400"
	label val vl_simple_400 vl_simple_400
	label var vl_simple_400 "Viral load: Neg/Suppressed<=400/Unsuppressed>400"

* Just 2013 guidance, for a datacheck later
gen vl_simple_2013 = .
	replace vl_simple_2013 = 0 if hiv5 == 1
	replace vl_simple_2013 = 1 if vl_exp <= 1000
	replace vl_simple_2013 = 2 if vl_exp > 1000 & !missing(vl_exp)
	cap label define vl_simple_2013 0 "HIV Negative" 1 "Suppressed<=1000" 2 "Unsuppressed>1000"
	label val vl_simple_2013 vl_simple_2013
	label var vl_simple_2013 "2013 Viral load: Neg/Suppressed<=1000/Unsuppressed>1000"

	tab vl_exp vl_simple_2013


/** drop people for whom exit date < survey visit date
    dropped 156 people: 34 participants, 120 not found, 2 refusals
	all migrated out before the survey visit date or before the next census
**/
drop if check<0

* test_outcome=. if individual died before survey (162) or was found ineligible at survey (212)
drop if test_outcome==.

	
**********************************************
* Setting Up Person-Year Survival Analyses *
**********************************************

*marking folks who die after July 31, 2019 as alive (will also censor them @ that day - see below)
tab exit_date if dead==1 & exit_date > date("31july2019", "DMY")
*84 ppl who die after july 31, 2019
replace dead = 0 if dead==1 & exit_date > date("31july2019", "DMY")

*censoring folks @ july 31, 2019
replace exit_date = date("31july2019", "DMY") if exit_date > date("31july2019", "DMY")

*svyset finalwt
stset exit_date, id(StudyNumber) enter(entry) origin(DoB) failure(dead) scale(365.25)

*Find proportion of year observed in first and last year of spell
gen wgtstart= int(_t0) +1 - _t0
gen wgtend= _t-int(_t)

*Calculate number of AgeYears in which person observed in this spell
gen N=int(_t)-int(_t0) + 1


*Expand by number of AgeYears in which person is observed
expand N

*Generate year of observation indicators: M=total number of years person observed, m= year of observation 1,..,M
sort StudyNumber
by StudyNumber: gen m=_n
by StudyNumber: gen M=_N
gen Yearcheck =M-N
tab Year
drop Yearcheck

*All years but the last have end=survives
gen EndYear=dead
replace EndYear=0 if m<M

* Age at start of this year
gen AgeYear= int(_t0) +m-1

*AgeGroup DUMMIES (15-29, 30-49, 50+)
gen ag_20 = 0
replace ag_20 = 1 if inrange(AgeYear,20,39)

gen ag_40 = 0
replace ag_40 = 1 if inrange(AgeYear,40,59)

gen ag_60 = 0
replace ag_60 = 1 if inrange(AgeYear,60,74)

gen ag_75 = 0
replace ag_75 = 1 if AgeYear>=75 & AgeYear!=.

*Categorical variable w/ age group to ease in interaction testing
gen agecat = .
replace agecat = 1 if ag_20 ==1 
replace agecat = 2 if ag_40 ==1 
replace agecat = 3 if ag_60 ==1
replace agecat = 4 if ag_75 ==1


*Generate weight = proportion of this age-year this person was observed
gen weight_py =1
replace weight_py = wgtstart if m==1
replace weight_py = wgtend if m==M
replace weight_py =1 if weight_py<1 & EndYear==1

*Creating final weight
gen wt_new = finalwt * weight_py 
svyset [pweight=wt_new]

**Keep person-years observed at ages 40+
keep if AgeYear>=40
xx
**Keep variables needed in analyses**
keep wt_new m M AgeYear outcome test_out EndYear dead agecat vl_simple_400 ///
	south_african mar3 edu working qses3 male systolic2 hiv_positive ///
	hyp_simple sbp_cat2 histbpmed diastolic2 vl_simple_2013 diastolic2 ///
	_t0 

rename outcome Outcome


*** Codebook taken at this point
codebook

save "HIVafter40_Twin_Epidemics_HIV_NCD.dta", replace	
